@@ -8,15 +8,16 @@ use std::io::prelude::*;
 use std::str::FromStr;
 
 use chrono::Datelike;
-use chrono::DateTime;
 use chrono::Local;
+use chrono::NaiveDateTime;
 use rand::Rng;
+use rbase64;
 use serde::ser::{Serialize, Serializer};
 #[cfg(unix)]
 use xattr::FileExt;
 
 use crate::fileinfo::FileInfo;
-use crate::util::format_date;
+use crate::util::{capitalize, format_date};
 use crate::util::format_datetime;
 use crate::util::parse_datetime;
 use crate::util::parse_filesize;
@@ -38,8 +39,8 @@ pub struct Variant {
     int_value: Option<i64>,
     float_value: Option<f64>,
     bool_value: Option<bool>,
-    dt_from: Option<DateTime<Local>>,
-    dt_to: Option<DateTime<Local>>,
+    dt_from: Option<NaiveDateTime>,
+    dt_to: Option<NaiveDateTime>,
 }
 
 impl Variant {
@@ -129,7 +130,7 @@ impl Variant {
         }
     }
 
-    pub fn from_datetime(value: DateTime<Local>) -> Variant {
+    pub fn from_datetime(value: NaiveDateTime) -> Variant {
         Variant {
             value_type: VariantType::DateTime,
             string_value: format_datetime(&value),
@@ -199,7 +200,7 @@ impl Variant {
         }
     }
 
-    pub fn to_datetime(&self) -> (DateTime<Local>, DateTime<Local>) {
+    pub fn to_datetime(&self) -> (NaiveDateTime, NaiveDateTime) {
         if self.dt_from.is_none() {
             match parse_datetime(&self.string_value) {
                 Ok((dt_from, dt_to)) => {
@@ -223,6 +224,7 @@ impl Display for Variant {
 pub enum Function {
     Lower,
     Upper,
+    InitCap,
     Length,
     ToBase64,
     FromBase64,
@@ -280,6 +282,8 @@ pub enum Function {
     HasXattr,
     #[cfg(unix)]
     Xattr,
+    #[cfg(target_os = "linux")]
+    HasCapabilities,
 
     Random,
 }
@@ -294,6 +298,7 @@ impl FromStr for Function {
             "lower" | "lowercase" | "lcase" => Ok(Function::Lower),
             "upper" | "uppercase" | "ucase" => Ok(Function::Upper),
             "length" | "len" => Ok(Function::Length),
+            "initcap" => Ok(Function::InitCap),
             "to_base64" | "base64" => Ok(Function::ToBase64),
             "from_base64" => Ok(Function::FromBase64),
             "bin" => Ok(Function::Bin),
@@ -350,6 +355,8 @@ impl FromStr for Function {
             "has_xattr" => Ok(Function::HasXattr),
             #[cfg(unix)]
             "xattr" => Ok(Function::Xattr),
+            #[cfg(target_os = "linux")]
+            "has_capabilities" | "has_caps" => Ok(Function::HasCapabilities),
 
             "rand" | "random" => Ok(Function::Random),
 
@@ -414,6 +421,11 @@ impl Function {
             return true;
         }
 
+        #[cfg(target_os = "linux")]
+        if self == &Function::HasCapabilities {
+            return true;
+        }
+
         match self {
             Function::Contains
             | Function::ContainsHiragana
@@ -438,14 +450,18 @@ pub fn get_value(function: &Option<Function>,
         Some(Function::Upper) => {
             return Variant::from_string(&function_arg.to_uppercase());
         },
+        Some(Function::InitCap) => {
+            let result = function_arg.split_whitespace().map(|s| capitalize(&s.to_lowercase())).collect::<Vec<_>>().join(" ");
+            return Variant::from_string(&result);
+        },
         Some(Function::Length) => {
             return Variant::from_int(function_arg.chars().count() as i64);
         },
         Some(Function::ToBase64) => {
-            return Variant::from_string(&base64::encode(&function_arg));
+            return Variant::from_string(&rbase64::encode((&function_arg).as_ref()));
         },
         Some(Function::FromBase64) => {
-            return Variant::from_string(&String::from_utf8(base64::decode(&function_arg).unwrap_or(vec![])).unwrap_or(String::new()));
+            return Variant::from_string(&String::from_utf8_lossy(&rbase64::decode(&function_arg).unwrap_or(vec![])).to_string());
         },
         Some(Function::Bin) => {
             return match function_arg.parse::<i64>() {
@@ -590,7 +606,7 @@ pub fn get_value(function: &Option<Function>,
             return Variant::empty(VariantType::String);
         }
         Some(Function::CurrentDate) => {
-            let now = Local::today();
+            let now = Local::now().date_naive();
             return Variant::from_string(&format_date(&now));
         }
         Some(Function::Year) => match parse_datetime(&function_arg) {
@@ -695,6 +711,18 @@ pub fn get_value(function: &Option<Function>,
 
             return Variant::empty(VariantType::String);
         }
+        #[cfg(target_os = "linux")]
+        Some(Function::HasCapabilities) => {
+            if let Some(entry) = entry {
+                if let Ok(file) = File::open(&entry.path()) {
+                    if let Ok(xattr) = file.get_xattr("security.capability") {
+                        return Variant::from_bool(xattr.is_some());
+                    }
+                }
+            }
+
+            return Variant::empty(VariantType::Bool);
+        }
         Some(Function::Random) => {
             let mut rng = rand::thread_rng();
 
