@@ -9,11 +9,12 @@ extern crate xattr;
 
 use std::env;
 use std::path::PathBuf;
+use std::process::ExitCode;
 
-use ansi_term::Colour::*;
 use atty::Stream;
+use nu_ansi_term::Color::*;
 use rustyline::error::ReadlineError;
-use rustyline::Editor;
+use rustyline::DefaultEditor;
 
 mod config;
 mod expr;
@@ -36,7 +37,7 @@ use crate::searcher::Searcher;
 use crate::util::error_message;
 use crate::util::str_to_bool;
 
-fn main() {
+fn main() -> ExitCode {
     let mut config = match Config::new() {
         Ok(cnf) => cnf,
         Err(err) => {
@@ -52,7 +53,7 @@ fn main() {
     #[cfg(windows)]
     {
         if !no_color {
-            let res = ansi_term::enable_ansi_support();
+            let res = nu_ansi_term::enable_ansi_support();
             let win_init_ok = match res {
                 Ok(()) => true,
                 Err(203) => true,
@@ -65,7 +66,7 @@ fn main() {
     if env::args().len() == 1 {
         short_usage_info(no_color);
         help_hint();
-        return;
+        return ExitCode::SUCCESS;
     }
 
     let mut args: Vec<String> = env::args().collect();
@@ -75,12 +76,12 @@ fn main() {
 
     if first_arg.contains("version") || first_arg.starts_with("-v") {
         short_usage_info(no_color);
-        return;
+        return ExitCode::SUCCESS;
     }
 
     if first_arg.contains("help") || first_arg.starts_with("-h") || first_arg.starts_with("/?") || first_arg.starts_with("/h") {
         usage_info(config, no_color);
-        return;
+        return ExitCode::SUCCESS;
     }
 
     let mut interactive = false;
@@ -111,7 +112,7 @@ fn main() {
             if !interactive {
                 short_usage_info(no_color);
                 help_hint();
-                return;
+                return ExitCode::SUCCESS;
             } else {
                 break;
             }
@@ -120,39 +121,54 @@ fn main() {
         first_arg = args[0].to_ascii_lowercase();
     }
 
+    let mut exit_value = None::<u8>;
+
     if interactive {
-        let mut rl = Editor::<()>::new();
-        loop {
-            let readline = rl.readline("query> ");
-            match readline {
-                Ok(query) => {
-                    rl.add_history_entry(query.as_str());
-                    exec_search(query, &config, no_color);
-                },
-                Err(ReadlineError::Interrupted) => {
-                    println!("CTRL-C");
-                    break
-                },
-                Err(ReadlineError::Eof) => {
-                    println!("CTRL-D");
-                    break
-                },
-                Err(err) => {
-                    let err = format!("{:?}", err);
-                    error_message("input", &err);
-                    break
+        match DefaultEditor::new() {
+            Ok(mut rl) => {
+                loop {
+                    let readline = rl.readline("query> ");
+                    match readline {
+                        Ok(query) => {
+                            let _ = rl.add_history_entry(query.as_str());
+                            exec_search(query, &config, no_color);
+                        },
+                        Err(ReadlineError::Interrupted) => {
+                            println!("CTRL-C");
+                            break
+                        },
+                        Err(ReadlineError::Eof) => {
+                            println!("CTRL-D");
+                            break
+                        },
+                        Err(err) => {
+                            let err = format!("{:?}", err);
+                            error_message("input", &err);
+                            break
+                        }
+                    }
                 }
+            },
+            _ => {
+                error_message("editor", "couldn't open line editor");
+                exit_value = Some(2);
             }
         }
     } else {
         let query = args.join(" ");
-        exec_search(query, &config, no_color);
+        exit_value = Some(exec_search(query, &config, no_color));
     }
 
     config.save();
+
+    if let Some(exit_value) = exit_value {
+        return ExitCode::from(exit_value);
+    }
+
+    ExitCode::SUCCESS
 }
 
-fn exec_search(query: String, config: &Config, no_color: bool) {
+fn exec_search(query: String, config: &Config, no_color: bool) -> u8 {
     let mut p = Parser::new();
     let query = p.parse(&query, config.debug);
 
@@ -166,9 +182,15 @@ fn exec_search(query: String, config: &Config, no_color: bool) {
             let use_colors = !no_color && is_terminal;
 
             let mut searcher = Searcher::new(query, config.clone(), use_colors);
-            searcher.list_search_results().unwrap()
+            searcher.list_search_results().unwrap();
+
+            let error_count = searcher.error_count;
+            match error_count {
+                0 => 0,
+                _ => 1
+            }
         },
-        Err(err) => error_message("query", &err)
+        Err(err) => { error_message("query", &err); 2 }
     }
 }
 
@@ -357,10 +379,12 @@ Functions:
     Xattr:
         HAS_XATTR                   Used to check if xattr exists (unix-only)
         XATTR                       Returns value of xattr (unix-only)
+        HAS_CAPABILITIES | HAS_CAPS Check if Linux capability exists for the file
     String:
         LENGTH | LEN                Returns length of string value
         LOWER | LOWERCASE | LCASE   Returns lowercase value
         UPPER | UPPERCASE | UCASE   Returns uppercase value
+        INITCAP                     Returns first letter of each word uppercase, all other letters lowercase
         TO_BASE64 | BASE64          Returns Base64 digest of a value
         FROM_BASE64                 Returns decoded value from a Base64 digest
         SUBSTRING | SUBSTR          Returns part of the string value
@@ -379,6 +403,7 @@ Functions:
         HEX                         Returns hexadecimal representation of an integer value
         OCT                         Returns octal representation of an integer value
         POWER | POW                 Raise the value to the specified power
+        SQRT                        Returns square root of the value
         CONTAINS                    Returns true, if file contains string, false if not
         COALESCE                    Returns first nonempty expression value
         CONCAT                      Returns concatenated string of expression values
