@@ -22,9 +22,8 @@ use std::path::PathBuf;
 use std::rc::Rc;
 use std::string::ToString;
 
-use chrono::Local;
-use chrono::TimeZone;
-use humansize::FileSize;
+use chrono::{Datelike, Local, Timelike};
+use humansize;
 use mp3_metadata;
 use mp3_metadata::MP3Metadata;
 use regex::Regex;
@@ -104,7 +103,7 @@ impl<T> Criteria<T> where T: Display {
 
     #[inline]
     fn cmp_at_datetimes(&self, other: &Self, i: usize) -> Ordering where T: Ord {
-        let default = Local.ymd(1970, 1, 1).and_hms(0, 0, 0);
+        let default = Local::now().naive_local().with_year(1970).unwrap().with_month(1).unwrap().with_day(1).unwrap().with_hour(0).unwrap().with_minute(0).unwrap().with_second(0).unwrap();
         let a = parse_datetime(&self.values[i].to_string()).unwrap_or((default, default)).0;
         let b = parse_datetime(&other.values[i].to_string()).unwrap_or((default, default)).0;
 
@@ -284,72 +283,72 @@ pub fn format_filesize(size: u64, modifier: &str) -> String {
 
     match modifier.as_str() {
         "b" | "byte" => {
-            fixed_at = humansize::file_size_opts::FixedAt::Byte;
-            format = humansize::file_size_opts::BINARY;
+            fixed_at = Some(humansize::FixedAt::Base);
+            format = humansize::BINARY;
         },
         "k" | "kib" => {
-            fixed_at = humansize::file_size_opts::FixedAt::Kilo;
-            format = humansize::file_size_opts::BINARY;
+            fixed_at = Some(humansize::FixedAt::Kilo);
+            format = humansize::BINARY;
             if zeroes == -1 {
                 zeroes = 0;
             }
         },
         "kb" => {
-            fixed_at = humansize::file_size_opts::FixedAt::Kilo;
-            format = humansize::file_size_opts::DECIMAL;
+            fixed_at = Some(humansize::FixedAt::Kilo);
+            format = humansize::DECIMAL;
             if zeroes == -1 {
                 zeroes = 0;
             }
         },
         "m" | "mib" => {
-            fixed_at = humansize::file_size_opts::FixedAt::Mega;
-            format = humansize::file_size_opts::BINARY;
+            fixed_at = Some(humansize::FixedAt::Mega);
+            format = humansize::BINARY;
             if zeroes == -1 {
                 zeroes = 0;
             }
         },
         "mb" => {
-            fixed_at = humansize::file_size_opts::FixedAt::Mega;
-            format = humansize::file_size_opts::DECIMAL;
+            fixed_at = Some(humansize::FixedAt::Mega);
+            format = humansize::DECIMAL;
             if zeroes == -1 {
                 zeroes = 0;
             }
         },
         "g" | "gib" => {
-            fixed_at = humansize::file_size_opts::FixedAt::Giga;
-            format = humansize::file_size_opts::BINARY;
+            fixed_at = Some(humansize::FixedAt::Giga);
+            format = humansize::BINARY;
         },
         "gb" => {
-            fixed_at = humansize::file_size_opts::FixedAt::Giga;
-            format = humansize::file_size_opts::DECIMAL;
+            fixed_at = Some(humansize::FixedAt::Giga);
+            format = humansize::DECIMAL;
         },
         "t" | "tib" => {
-            fixed_at = humansize::file_size_opts::FixedAt::Tera;
-            format = humansize::file_size_opts::BINARY;
+            fixed_at = Some(humansize::FixedAt::Tera);
+            format = humansize::BINARY;
         },
         "tb" => {
-            fixed_at = humansize::file_size_opts::FixedAt::Tera;
-            format = humansize::file_size_opts::DECIMAL;
+            fixed_at = Some(humansize::FixedAt::Tera);
+            format = humansize::DECIMAL;
         },
         "p" | "pib" => {
-            fixed_at = humansize::file_size_opts::FixedAt::Peta;
-            format = humansize::file_size_opts::BINARY;
+            fixed_at = Some(humansize::FixedAt::Peta);
+            format = humansize::BINARY;
         },
         "pb" => {
-            fixed_at = humansize::file_size_opts::FixedAt::Peta;
-            format = humansize::file_size_opts::DECIMAL;
+            fixed_at = Some(humansize::FixedAt::Peta);
+            format = humansize::DECIMAL;
         },
         "e" | "eib" => {
-            fixed_at = humansize::file_size_opts::FixedAt::Exa;
-            format = humansize::file_size_opts::BINARY;
+            fixed_at = Some(humansize::FixedAt::Exa);
+            format = humansize::BINARY;
         },
         "eb" => {
-            fixed_at = humansize::file_size_opts::FixedAt::Exa;
-            format = humansize::file_size_opts::DECIMAL;
+            fixed_at = Some(humansize::FixedAt::Exa);
+            format = humansize::DECIMAL;
         },
         "" => {
-            fixed_at = humansize::file_size_opts::FixedAt::No;
-            format = humansize::file_size_opts::BINARY;
+            fixed_at = None;
+            format = humansize::BINARY;
         },
         _ => {
             panic!("Unknown file size modifier");
@@ -361,24 +360,20 @@ pub fn format_filesize(size: u64, modifier: &str) -> String {
     }
 
     if conventional {
-        format = humansize::file_size_opts::CONVENTIONAL;
+        format = humansize::WINDOWS;
     }
 
     if decimal {
-        format = humansize::file_size_opts::DECIMAL;
+        format = humansize::DECIMAL;
     }
 
-    let formatter = humansize::file_size_opts::FileSizeOpts {
-        fixed_at,
-        decimal_places: zeroes as usize,
-        space,
-        ..format
-    };
+    let format_options = humansize::FormatSizeOptions::from(format)
+        .fixed_at(fixed_at)
+        .decimal_places(zeroes as usize)
+        .space_after_value(space);
 
-    let mut result = match size.file_size(formatter) {
-        Ok(size) => size,
-        _ => String::new()
-    };
+    let mut result = humansize::format_size(size, format_options)
+        .replace("kB", "KB");
 
     if short_units {
         result = result
@@ -403,6 +398,14 @@ pub fn str_to_bool(val: &str) -> Option<bool> {
     }
 }
 
+pub fn capitalize(s: &str) -> String {
+    let mut c = s.chars();
+    match c.next() {
+        Some(f) => f.to_uppercase().collect::<String>() + c.as_str(),
+        None => String::new()
+    }
+}
+
 pub fn parse_unix_filename(s: &str) -> &str {
     let last_slash = s.rfind('/');
     match last_slash {
@@ -437,9 +440,11 @@ pub fn is_text_mime(mime: &str) -> bool {
 pub fn canonical_path(path_buf: &PathBuf) -> Result<String, String> {
     match canonicalize(path_buf) {
         Ok(path) => Ok(format_absolute_path(&path)),
-        Err(err) => match err.kind() {
-            std::io::ErrorKind::Other => Ok(format_absolute_path(&path_buf)),
-            _ => Err(err.to_string())
+        Err(err) => {
+            match err.to_string().starts_with("Incorrect function.") {
+                true => Ok(format_absolute_path(&path_buf)),
+                _ => Err(err.to_string())
+            }
         }
     }
 }
@@ -799,4 +804,12 @@ mod tests {
         assert_eq!(get_extension("has_ext.foobar"), String::from("foobar"));
         assert_eq!(get_extension("has.extension.foo"), String::from("foo"));
     }
+
+    #[test]
+    fn test_capitalize() {
+        assert_eq!(capitalize(""), String::new());
+        assert_eq!(capitalize("test"), String::from("Test"));
+        assert_eq!(capitalize("some test"), String::from("Some test"));
+        assert_eq!(capitalize("превед медвед"), String::from("Превед медвед"));
+    }
 }
